//
// Copyright (C) 1999-2004 Toshikaz Hirabayashi
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to
// deal in the Software without restriction, including without limitation the
// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
// sell copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
// TOSHIKAZ HIRABAYASHI BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF
// OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.
// Except as contained in this notice, the name of Toshikaz Hirabayashi shall 
// not be used in advertising or otherwise to promote the sale, use or other 
// dealings in this Software without prior written authorization from  
// Toshikaz Hirabayashi.


#ifndef WSDWINSCRDEV_H
#define WSDWINSCRDEV_H

#include <win/WSDwinformDev.h>

class WSDwinScrFrameDev               :public WSDwinformDev {

  private:
  protected:
    HWND      _scr_wnd;
    short     _h_scr_pos;
    short     _v_scr_pos;
    WSCushort  _work_width;
    WSCushort  _work_height;
    WSCushort  _title_height;

    virtual long createWindow();
    virtual long createPixmap();
    virtual long destroyWindow();
virtual void _evh_delete(WinEvent*);
virtual void _evh_resize(WinEvent*);
virtual void _evh_expose(WinEvent*);
    void _expose_children(int x,int y,unsigned long w,unsigned long h);

  public:
    WSDwinScrFrameDev();
    virtual ~WSDwinScrFrameDev();
    virtual long setVisible(WSCbool fl);
    virtual long setValue(long kind,void*);
    virtual void getDispAddr(short*,short*);
    virtual void _clear_and_expose();
    WSMFclassDef(WSDwinScrFrameDev,WSDwinformDev);
};

#endif
